.. _proxy:

*****
Proxy
*****

.. _proxy-controllers:

Proxy Controllers
=================

Base
~~~~

.. automodule:: swift.proxy.controllers.base
    :members:
    :undoc-members:
    :show-inheritance:

Account
~~~~~~~

.. automodule:: swift.proxy.controllers.account
    :members:
    :undoc-members:
    :show-inheritance:

Container
~~~~~~~~~

.. automodule:: swift.proxy.controllers.container
    :members:
    :undoc-members:
    :show-inheritance:

Object
~~~~~~

.. automodule:: swift.proxy.controllers.obj
    :members:
    :undoc-members:
    :show-inheritance:

.. _proxy-server:

Proxy Server
============

.. automodule:: swift.proxy.server
    :members:
    :undoc-members:
    :show-inheritance:
